@@ -257,6 +257,6 @@ LL=function(trat,
                                rmse))
   graficos=list("Coefficients"=coef,
                 "values"=graphs,
-                graph)
-  print(graficos)
+                "plot"=graph)
+  graficos
 }
