@@ -451,7 +451,7 @@ LM=function(trat,
                                rmse))
   graficos=list("Coefficients"=models,
                 "values"=graphs,
-                grafico,
+                "plot"=grafico,
                 "VIF"=vif)
-  print(graficos)
+  graficos
 }
