@@ -149,8 +149,8 @@ regression=function(trat,
   if(model=="BC4"){a=BC(trat, resp, npar="BC.4", ylab = ylab, xlab = xlab, theme = theme, legend.position = legend.position,point = point,width.bar = width.bar,textsize = textsize, pointsize = pointsize,linesize = linesize,pointshape = pointshape,round = round,fontfamily = fontfamily,error = error,xname.formula = xname.formula,yname.formula = yname.formula)}
   if(model=="BC5"){a=BC(trat, resp, npar="BC.5", ylab = ylab, xlab = xlab, theme = theme, legend.position = legend.position,point = point,width.bar = width.bar,textsize = textsize, pointsize = pointsize,linesize = linesize,pointshape = pointshape,round = round,fontfamily = fontfamily,error = error,xname.formula = xname.formula,yname.formula = yname.formula)}
 
-  if(model=="CD4"){a=CD(trat, resp, npar="CD.4", ylab = ylab, xlab = xlab, theme = theme, legend.position =  legend.position,point = point,width.bar = width.bar,textsize = textsize, pointsize = pointsize,linesize = linesize,pointshape = pointshape,round = round,fontfamily = fontfamily,error = error,xname.formula = xname.formula,yname.formula = yname.formula)}
-  if(model=="CD5"){a=CD(trat, resp, npar="CD.5", ylab = ylab, xlab = xlab, theme = theme, legend.position =  legend.position,point = point,width.bar = width.bar,textsize = textsize, pointsize = pointsize,linesize = linesize,pointshape = pointshape,round = round,fontfamily = fontfamily,error = error,xname.formula = xname.formula,yname.formula = yname.formula)}
+  if(model=="CD4"){a=CD(trat, resp, npar="CRS.4", ylab = ylab, xlab = xlab, theme = theme, legend.position =  legend.position,point = point,width.bar = width.bar,textsize = textsize, pointsize = pointsize,linesize = linesize,pointshape = pointshape,round = round,fontfamily = fontfamily,error = error,xname.formula = xname.formula,yname.formula = yname.formula)}
+  if(model=="CD5"){a=CD(trat, resp, npar="CRS.5", ylab = ylab, xlab = xlab, theme = theme, legend.position =  legend.position,point = point,width.bar = width.bar,textsize = textsize, pointsize = pointsize,linesize = linesize,pointshape = pointshape,round = round,fontfamily = fontfamily,error = error,xname.formula = xname.formula,yname.formula = yname.formula)}
 
   if(model=="weibull3"){a=weibull(trat, resp, ylab = ylab, xlab = xlab, theme = theme, legend.position =  legend.position,point = point,width.bar = width.bar,textsize = textsize, pointsize = pointsize,linesize = linesize,pointshape = pointshape,round = round,fontfamily = fontfamily,error = error,xname.formula = xname.formula,yname.formula = yname.formula)}
   if(model=="weibull4"){a=weibull(trat, resp, npar="w4",ylab = ylab, xlab = xlab, theme = theme, legend.position =  legend.position,point = point,width.bar = width.bar,textsize = textsize, pointsize = pointsize,linesize = linesize,pointshape = pointshape,round = round,fontfamily = fontfamily,error = error,xname.formula = xname.formula,yname.formula = yname.formula)}
